@@ -546,7 +546,7 @@ format_inactivity_value_cb (GtkScale *scale, gdouble value, gpointer data)
 {
     gint h, min;
     
-    if ( (gint)value <= 30 )
+    if ( (gint)value <= 14 )
 	return g_strdup (_("Never"));
     else if ( (gint)value < 60 )
 	return g_strdup_printf ("%d %s", (gint)value, _("Minutes"));
@@ -746,7 +746,7 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
 	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not permitted"));
     }
     
-    val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX ON_BATTERY_INACTIVITY_TIMEOUT, 30);
+    val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX ON_BATTERY_INACTIVITY_TIMEOUT, 14);
     gtk_range_set_value (GTK_RANGE (inact), val);
     
     
@@ -922,7 +922,7 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean c
 	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not permitted"));
     }
     
-    val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX ON_AC_INACTIVITY_TIMEOUT, 30);
+    val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX ON_AC_INACTIVITY_TIMEOUT, 14);
     gtk_range_set_value (GTK_RANGE (inact), val);
    
 #ifdef HAVE_DPMS
@@ -1046,7 +1046,7 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     GtkListStore *list_store;
     GtkTreeIter iter;
     
-    list_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+    list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
     
     tray = GTK_WIDGET (gtk_builder_get_object (xml, "tray-combox"));
     gtk_combo_box_set_model (GTK_COMBO_BOX(tray), GTK_TREE_MODEL(list_store));
@@ -1060,6 +1060,9 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     gtk_list_store_append(list_store, &iter);
     gtk_list_store_set (list_store, &iter, 0, _("When battery is charging or discharging"), 1, SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING, -1);
     
+    gtk_list_store_append(list_store, &iter);
+    gtk_list_store_set (list_store, &iter, 0, _("Never show icon"), 1, NEVER_SHOW_ICON, -1);
+    
     value = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX SHOW_TRAY_ICON_CFG, SHOW_ICON_WHEN_BATTERY_PRESENT);
     
     for ( valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store), &iter);
@@ -1286,6 +1289,7 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     
     if ( !can_suspend )
     {
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (inact_hibernate), TRUE);
 	gtk_widget_set_sensitive (inact_suspend, FALSE);
 	gtk_widget_set_tooltip_text (inact_suspend, _("Suspend operation not permitted"));
     }
@@ -1582,8 +1586,6 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop,
     dialog = GTK_WIDGET (gtk_builder_get_object (xml, "xfpm-settings-dialog"));
     nt = GTK_WIDGET (gtk_builder_get_object (xml, "main-notebook"));
     
-    gtk_builder_connect_signals (xml, channel);
-
     xfpm_settings_on_ac (channel, user_privilege, can_suspend, can_hibernate, has_lcd_brightness, has_lid );
     
     if ( system_laptop )
@@ -1611,4 +1613,6 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop,
 	g_signal_connect (dialog, "response", G_CALLBACK (dialog_response_cb), channel);
 	gtk_widget_show (dialog);
     }
+    
+    gtk_builder_connect_signals (xml, channel);
 }
