@@ -280,7 +280,6 @@ xfpm_engine_button_pressed_cb (XfpmButton *button,
 	g_object_get (G_OBJECT (engine->priv->conf),
 		      SLEEP_SWITCH_CFG, &req,
 		      NULL);
-	g_print ("req %d\n", req);
     }
     else if ( type == BUTTON_HIBERNATE )
     {
@@ -418,17 +417,17 @@ xfpm_engine_set_inactivity_timeouts (XfpmEngine *engine)
 		  NULL);
     
 #ifdef DEBUG
-    if ( on_ac == 30 )
+    if ( on_ac == 14 )
 	TRACE ("setting inactivity sleep timeout on ac to never");
     else
 	TRACE ("setting inactivity sleep timeout on ac to %d", on_ac);
-    if ( on_battery == 30 )
+    if ( on_battery == 14 )
 	TRACE ("setting inactivity sleep timeout on battery to never");
     else
 	TRACE ("setting inactivity sleep timeout on battery to %d", on_battery);
 #endif
     
-    if ( on_ac == 30 )
+    if ( on_ac == 14 )
     {
 	xfpm_idle_free_alarm (engine->priv->idle, TIMEOUT_INACTIVITY_ON_AC );
     }
@@ -437,7 +436,7 @@ xfpm_engine_set_inactivity_timeouts (XfpmEngine *engine)
 	xfpm_idle_set_alarm (engine->priv->idle, TIMEOUT_INACTIVITY_ON_AC, on_ac * 1000 * 60);
     }
     
-    if ( on_battery == 30 )
+    if ( on_battery == 14 )
     {
 	xfpm_idle_free_alarm (engine->priv->idle, TIMEOUT_INACTIVITY_ON_BATTERY );
     }
@@ -690,6 +689,9 @@ void xfpm_engine_reload_hal_objects (XfpmEngine *engine)
  */
 static gboolean xfpm_engine_dbus_shutdown (XfpmEngine *engine,
 					   GError **error);
+
+static gboolean xfpm_engine_dbus_reboot   (XfpmEngine *engine,
+					   GError **error);
 					   
 static gboolean xfpm_engine_dbus_hibernate (XfpmEngine * engine,
 					    GError **error);
@@ -697,6 +699,14 @@ static gboolean xfpm_engine_dbus_hibernate (XfpmEngine * engine,
 static gboolean xfpm_engine_dbus_suspend (XfpmEngine * engine,
 					  GError ** error);
 
+static gboolean xfpm_engine_dbus_can_reboot (XfpmEngine * engine,
+					     gboolean * OUT_can_reboot, 
+					     GError ** error);
+
+static gboolean xfpm_engine_dbus_can_shutdown (XfpmEngine * engine,
+					       gboolean * OUT_can_reboot, 
+					       GError ** error);
+
 static gboolean xfpm_engine_dbus_can_hibernate (XfpmEngine * engine,
 						gboolean * OUT_can_hibernate,
 						GError ** error);
@@ -705,6 +715,10 @@ static gboolean xfpm_engine_dbus_can_suspend (XfpmEngine * engine,
 					      gboolean * OUT_can_suspend,
 					      GError ** error);
 
+static gboolean xfpm_engine_dbus_get_power_save_status (XfpmEngine * engine,
+						        gboolean * OUT_save_power,
+						        GError ** error);
+
 static gboolean xfpm_engine_dbus_get_on_battery (XfpmEngine * engine,
 						 gboolean * OUT_on_battery,
 						 GError ** error);
@@ -720,10 +734,6 @@ xfpm_engine_dbus_class_init (XfpmEngineClass * klass)
 {
     dbus_g_object_type_install_info (G_TYPE_FROM_CLASS (klass),
 				     &dbus_glib_xfpm_engine_object_info);
-
-    dbus_g_error_domain_register (XFPM_ERROR,
-				  "org.freedesktop.PowerManagement",
-				  XFPM_TYPE_ERROR);
 }
 
 static void
@@ -762,6 +772,32 @@ static gboolean xfpm_engine_dbus_shutdown (XfpmEngine *engine,
     return TRUE;
 }
 
+static gboolean xfpm_engine_dbus_reboot   (XfpmEngine *engine,
+					   GError **error)
+{
+    gboolean caller_privilege;
+    
+    TRACE ("Reboot message received");
+
+    g_object_get (G_OBJECT (engine->priv->shutdown),
+		  "caller-privilege", &caller_privilege,
+		  NULL);
+
+    if (!caller_privilege)
+    {
+	g_set_error (error, XFPM_ERROR, XFPM_ERROR_PERMISSION_DENIED,
+		    _("Permission denied"));
+	return FALSE;
+    }
+
+    if ( engine->priv->inhibited )
+	return TRUE;
+
+    xfpm_reboot (engine->priv->shutdown, NULL);
+    
+    return TRUE;
+}
+
 static gboolean
 xfpm_engine_dbus_hibernate (XfpmEngine * engine, GError ** error)
 {
@@ -782,7 +818,7 @@ xfpm_engine_dbus_hibernate (XfpmEngine * engine, GError ** error)
 
     if (!can_hibernate)
     {
-	g_set_error (error, XFPM_ERROR, XFPM_ERROR_HIBERNATE_NOT_SUPPORTED,
+	g_set_error (error, XFPM_ERROR, XFPM_ERROR_NO_HARDWARE_SUPPORT,
 		    _("Hibernate not supported"));
 	return FALSE;
     }
@@ -811,7 +847,7 @@ xfpm_engine_dbus_suspend (XfpmEngine * engine, GError ** error)
 
     if (!can_suspend)
     {
-	g_set_error (error, XFPM_ERROR, XFPM_ERROR_SUSPEND_NOT_SUPPORTED,
+	g_set_error (error, XFPM_ERROR, XFPM_ERROR_NO_HARDWARE_SUPPORT,
 		    _("Suspend not supported"));
 	return FALSE;
     }
@@ -821,6 +857,30 @@ xfpm_engine_dbus_suspend (XfpmEngine * engine, GError ** error)
     return TRUE;
 }
 
+static gboolean
+xfpm_engine_dbus_can_shutdown (XfpmEngine * engine,
+			       gboolean * OUT_can_shutdown, GError ** error)
+{
+    TRACE ("Can shutdown message received");
+    
+    g_object_get (G_OBJECT (engine->priv->shutdown),
+		  "caller-privilege", OUT_can_shutdown, NULL);
+
+    return TRUE;
+}
+
+static gboolean
+xfpm_engine_dbus_can_reboot (XfpmEngine * engine,
+			     gboolean * OUT_can_reboot, GError ** error)
+{
+    TRACE ("Can reboot message received");
+    
+    g_object_get (G_OBJECT (engine->priv->shutdown),
+		  "caller-privilege", OUT_can_reboot, NULL);
+
+    return TRUE;
+}
+
 static gboolean
 xfpm_engine_dbus_can_hibernate (XfpmEngine * engine,
 				gboolean * OUT_can_hibernate, GError ** error)
@@ -843,6 +903,23 @@ xfpm_engine_dbus_can_suspend (XfpmEngine * engine,
     return TRUE;
 }
 
+static gboolean xfpm_engine_dbus_get_power_save_status (XfpmEngine * engine,
+						        gboolean * OUT_save_power,
+						        GError ** error)
+{
+    gboolean save_power;
+    
+    TRACE ("Can power save message received");
+    
+    g_object_get (G_OBJECT (engine->priv->conf),
+		  POWER_SAVE_ON_BATTERY, &save_power,
+		  NULL);
+		  
+    *OUT_save_power = save_power && engine->priv->on_battery;
+    
+    return TRUE;
+}
+
 static gboolean
 xfpm_engine_dbus_get_on_battery (XfpmEngine * engine,
 				 gboolean * OUT_on_battery, GError ** error)
