@@ -144,7 +144,7 @@ xfpm_xfconf_load (XfpmXfconf *conf, gboolean channel_valid)
     for ( i = 0; i < nspecs; i++)
     {
 	gchar *prop_name;
-	prop_name = g_strdup_printf ("/%s", specs[i]->name);
+	prop_name = g_strdup_printf ("%s%s", PROPERTIES_PREFIX, specs[i]->name);
 	g_value_init (&value, specs[i]->value_type);
 	
 	if (channel_valid)
@@ -269,7 +269,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                      g_param_spec_uint (SHOW_TRAY_ICON_CFG,
                                                         NULL, NULL,
 							SHOW_ICON_ALWAYS,
-							SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING,
+							NEVER_SHOW_ICON,
 							SHOW_ICON_WHEN_BATTERY_PRESENT,
                                                         G_PARAM_READWRITE));
 							
@@ -416,7 +416,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                         NULL, NULL,
 							0,
 							G_MAXUINT,
-							30,
+							14,
                                                         G_PARAM_READWRITE));
 
     /**
@@ -428,7 +428,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                         NULL, NULL,
 							0,
 							G_MAXUINT,
-							30,
+							14,
                                                         G_PARAM_READWRITE));
 
      /**
